@@ -47,7 +47,7 @@ QString OctaveBackend::id() const
 
 QString OctaveBackend::version() const
 {
-    return QLatin1String("4.0 and 4.2");
+    return QLatin1String("5.0 and 5.1");
 }
 
 Cantor::Backend::Capabilities OctaveBackend::capabilities() const
@@ -66,9 +66,25 @@ Cantor::Session* OctaveBackend::createSession()
     return new OctaveSession(this);
 }
 
-bool OctaveBackend::requirementsFullfilled() const
+bool OctaveBackend::requirementsFullfilled(QString* const reason) const
 {
-    return QFileInfo(OctaveSettings::path().toLocalFile()).isExecutable();
+    const QString& replPath = OctaveSettings::path().toLocalFile();
+    if (replPath.isEmpty())
+    {
+        if (reason)
+            *reason = i18n("Octave backend needs installed Octave programming language. The backend often automatically finds needed Octave binary file, but not in this case. Please, go to Cantor settings and set path to Octave binary file with command line interface (CLI)");
+        return false;
+    }
+
+    QFileInfo info(replPath);
+    if (info.isExecutable())
+        return true;
+    else
+    {
+        if (reason)
+            *reason = i18n("In Octave backend settings a path to Octave binary file set as %1, but this file not executable. Are you sure, that this is correct path to Octave? Change this path in Cantor settings, if no.").arg(replPath);
+        return false;
+    }
 }
 
 QUrl OctaveBackend::helpUrl() const
