@@ -52,6 +52,8 @@ private Q_SLOTS:
     void testInvalidSyntax();
 
     void testCompletion();
+    void testHelpRequest();
+    void testSyntaxHelp();
 
     //tests variable model
     void testVariablesCreatingFromCode();
@@ -61,8 +63,8 @@ private Q_SLOTS:
     //tests doing a plot
     void testPlot();
 
-
-
+    void testLoginLogout();
+    void testRestartWhileRunning();
 private:
     QString backendName() override;
 };
