@@ -28,13 +28,13 @@ class CANTOR_PYTHONBACKEND_EXPORT PythonBackend : public Cantor::Backend
 {
   Q_OBJECT
   public:
-    explicit PythonBackend(QObject* parent = nullptr, const QList<QVariant> args = QList<QVariant>());
+    explicit PythonBackend(QObject* parent = nullptr, const QList<QVariant>& args = QList<QVariant>());
     ~PythonBackend() override;
 
-    Cantor::Backend::Capabilities capabilities() const override;
-
     QWidget* settingsWidget(QWidget* parent) const override;
+
     KConfigSkeleton* config() const override = 0;
+    Cantor::Backend::Capabilities capabilities() const override = 0;
 };
 
 
