@@ -28,15 +28,28 @@ class TestPython2 : public BackendTest
 {
   Q_OBJECT
   private Q_SLOTS:
-    void testImportNumpy();
     void testCodeWithComments();
     void testSimpleCode();
     void testMultilineCode();
+    void testCommandQueue();
+
+    void testSimplePlot();
+
+    void testImportStatement();
+    void testInvalidSyntax();
+
+    void testSimpleExpressionWithComment();
+    void testCommentExpression();
+    void testMultilineCommandWithComment();
 
     void testVariablesCreatingFromCode();
     void testVariableCleanupAfterRestart();
     void testDictVariable();
 
+    void testCompletion();
+    void testInterrupt();
+
+    void testWarning();
   private:
     QString backendName() override;
 };
